@@ -24,6 +24,7 @@ def invoke_semgrep(paths, scan_rules, **kwargs):
             output_format=OutputFormat.JSON,
             output_destination=None,
             error_on_findings=False,
+            verbose_errors=False,
             strict=False,
             timeout_threshold=3,
         ),
@@ -35,7 +36,7 @@ def invoke_semgrep(paths, scan_rules, **kwargs):
         jobs=cpu_count,
         pattern=None,
         lang=None,
-        config=scan_rules,
+        configs=[scan_rules],
         timeout=5,
         timeout_threshold=3,
         **kwargs,
